/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'devtools', 'sv', {
	title: 'Elementinformation',
	dialogName: 'Dialogrutans namn',
	tabName: 'Fliknamn',
	elementId: 'Element-ID',
	elementType: 'Element-typ'
} );
